@@ -4,7 +4,7 @@ def build_signature(**kwargs):
     for key, value in dict(sorted_kwargs_list).items():
         if value is None:
             continue
-        ret += str(key) + str(value)
+        ret += str(key) + str(value).replace(" ", "")
     return ret
 
 
@@ -18,7 +18,10 @@ def build_param(method, **kwargs):
 
     salt = int(datetime.now().timestamp())
     signature_raw = (
-        build_signature(**kwargs) + "method" + method + api_secret + str(salt)
+        # build_signature(method=method, **kwargs) + "method" + method + api_secret + str(salt)
+        build_signature(method=method, **kwargs)
+        + api_secret
+        + str(salt)
     )
     signature_encoded = signature_raw.encode()
     signature = sha1(signature_encoded)
